# jeepr

GPR utilities

[![Travis build status](https://img.shields.io/travis/agile-geoscience/jeepr.svg)](https://travis-ci.org/agile-geoscience/jeepr)
    
[![Development Status](https://img.shields.io/pypi/status/jeepr.svg)](https://pypi.python.org/pypi/jeepr/)

[![Latest version](https://img.shields.io/pypi/v/jeepr.svg)](https://pypi.python.org/pypi/jeepr/)
    
[![Python version](https://img.shields.io/pypi/pyversions/jeepr.svg)](https://pypi.python.org/pypi/jeepr/)
    
[![License](https://img.shields.io/pypi/l/jeepr.svg)](http://www.apache.org/licenses/LICENSE-2.0)

[![Documentation Status](https://readthedocs.org/projects/jeepr/badge/?version=latest)](http://jeepr.readthedocs.io/en/latest/?badge=latest)


This project is in alpha. You should probably ignore it.

Do this:

    conda env create -f environment.yml

Note, if you're not using the `environment.yml` file, you need a special version of VTK, compiled against Python 3.6:

    conda install -c clinicalgraphics vtk 


© 2017 Agile Scientific
